@@ -71,8 +71,8 @@ ENABLE_WEBVFX=1
 WEBVFX_HEAD=1
 WEBVFX_REVISION=
 ENABLE_RUBBERBAND=1
-RUBBERBAND_HEAD=0
-RUBBERBAND_REVISION=mlt_patches
+RUBBERBAND_HEAD=1
+RUBBERBAND_REVISION=
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
 # QT_LIB_DIR="$(pkg-config --variable=prefix QtCore)/lib"
@@ -462,11 +462,11 @@ function set_globals {
   REPOLOCS[11]="git://github.com/anholt/libepoxy.git"
   REPOLOCS[12]="https://git.opus-codec.org/opus.git"
   REPOLOCS[13]="https://github.com/videolan/x265"
-  REPOLOCS[14]="https://bitbucket.org/eigen/eigen/get/3.2.4.tar.gz"
+  REPOLOCS[14]="https://gitlab.com/libeigen/eigen.git"
   REPOLOCS[15]="git://github.com/FFmpeg/nv-codec-headers.git"
   REPOLOCS[16]="git://github.com/GPUOpen-LibrariesAndSDKs/AMF.git"
   REPOLOCS[17]="git://github.com/lu-zero/mfx_dispatch.git"
-  REPOLOCS[18]="git://github.com/bmatherly/rubberband.git"
+  REPOLOCS[18]="git://github.com/breakfastquay/rubberband.git"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -483,7 +483,7 @@ function set_globals {
   REPOTYPES[11]="git"
   REPOTYPES[12]="git"
   REPOTYPES[13]="git"
-  REPOTYPES[14]="http-tgz"
+  REPOTYPES[14]="git"
   REPOTYPES[15]="git"
   REPOTYPES[16]="git"
   REPOTYPES[17]="git"
@@ -541,7 +541,7 @@ function set_globals {
   if test 0 = "$X265_HEAD" -a "$X265_REVISION" ; then
     REVISIONS[13]="$X265_REVISION"
   fi
-  REVISIONS[14]="eigen-eigen-10219c95fe65"
+  REVISIONS[14]="3.2.4"
   REVISIONS[15]="sdk/8.1"
   REVISIONS[16]=""
   REVISIONS[17]="1.25"
@@ -1546,6 +1546,11 @@ function configure_compile_install_subproject {
   # Configure
   feedback_status Configuring $1
 
+  # Special hack for ffmpeg
+  if [ "FFmpeg" = "$1" ] && [ "$TARGET_OS" = "Win32" -o "$TARGET_OS" = "Win64" ]; then
+    cmd sed 's/fopen(/av_fopen_utf8(/' -i libavfilter/vf_lut3d.c
+  fi
+
   # Special hack for frei0r
   if test "frei0r" = "$1" -a ! -e configure ; then
     debug "Need to create configure for $1"
@@ -1622,6 +1627,7 @@ function configure_compile_install_subproject {
     if [ "$TARGET_OS" = "Darwin" ]; then
       cmd sed -e 's/-Wl,-Bsymbolic//' -i .bak Makefile
       cmd sed -e 's/-Wl,-soname=$(LIBNAME)$(DYNAMIC_EXTENSION).$(DYNAMIC_ABI_VERSION)//' -i .bak Makefile
+      cmd sed -e 's/\.so/\.dylib/' -i .bak Makefile
     elif [ "$TARGET_OS" = "Win32" -o "$TARGET_OS" = "Win64" ]; then
       cmd grep -q fftw3 rubberband.pc.in || sed 's/-lrubberband/-lrubberband -lfftw3-3 -lsamplerate/' -i rubberband.pc.in
     fi
@@ -1712,6 +1718,12 @@ function configure_compile_install_subproject {
       log X265LIB=$X265LIB
       cmd install_name_tool -id "$FINAL_INSTALL_DIR"/lib/$(basename "$X265LIB") "$FINAL_INSTALL_DIR"/lib/libx265.dylib
     fi
+    if test "rubberband" = "$1" -a "Darwin" = "$TARGET_OS" ; then
+      # replace @rpath with full path to lib
+      RUBBERBANDLIB=$(otool -D "$FINAL_INSTALL_DIR"/lib/librubberband.dylib | tail -n 1)
+      log RUBBERBANDLIB=$RUBBERBANDLIB
+      cmd install_name_tool -id "$FINAL_INSTALL_DIR"/lib/$(basename "$RUBBERBANDLIB") "$FINAL_INSTALL_DIR"/lib/librubberband.dylib
+    fi
   fi
   feedback_progress Done installing $1
 
