@@ -341,6 +341,7 @@ void EncodeDock::loadPresetFromProperties(Mlt::Properties& preset)
             other.append(QString("%1=%2").arg(name).arg(preset.get(i)));
         }
     }
+    filterX265Params(other);
     ui->advancedTextEdit->setPlainText(other.join("\n"));
 
     // normalize the quality settings
@@ -768,10 +769,22 @@ Mlt::Properties* EncodeDock::collectProperties(int realtime)
                     setIfNotSet(p, "connection_type", "x11");
                 }
             }
-            setIfNotSet(p, "width", ui->widthSpinner->value());
-            setIfNotSet(p, "height", ui->heightSpinner->value());
-            setIfNotSet(p, "aspect", double(ui->aspectNumSpinner->value()) / double(ui->aspectDenSpinner->value()));
-            setIfNotSet(p, "progressive", ui->scanModeCombo->currentIndex());
+            if (ui->widthSpinner->value() != MLT.profile().width()) {
+                setIfNotSet(p, "width", ui->widthSpinner->value());
+            }
+            if (ui->heightSpinner->value() != MLT.profile().height()) {
+                setIfNotSet(p, "height", ui->heightSpinner->value());
+            }
+            if (ui->previewScaleCheckBox->isChecked() && !p->get("scale") && Settings.playerPreviewScale() > 0) {
+                p->set("scale", double(Settings.playerPreviewScale()) / MLT.profile().height());
+            }
+            if (ui->aspectNumSpinner->value() != MLT.profile().display_aspect_num() ||
+                ui->aspectDenSpinner->value() != MLT.profile().display_aspect_den()) {
+                setIfNotSet(p, "aspect", double(ui->aspectNumSpinner->value()) / double(ui->aspectDenSpinner->value()));
+            }
+            if (ui->scanModeCombo->currentIndex() != MLT.profile().progressive()) {
+                setIfNotSet(p, "progressive", ui->scanModeCombo->currentIndex());
+            }
             setIfNotSet(p, "top_field_first", ui->fieldOrderCombo->currentIndex());
             switch (ui->deinterlacerCombo->currentIndex()) {
             case 0:
@@ -863,6 +876,10 @@ void EncodeDock::collectProperties(QDomElement& node, int realtime)
 
 MeltJob* EncodeDock::createMeltJob(Mlt::Producer* service, const QString& target, int realtime, int pass)
 {
+    QString caption = tr("Export File");
+    if (Util::warnIfNotWritable(target, this, caption, true /* remove */))
+        return nullptr;
+
     // if image sequence, change filename to include number
     QString mytarget = target;
     if (!ui->disableVideoCheckbox->isChecked()) {
@@ -893,33 +910,29 @@ MeltJob* EncodeDock::createMeltJob(Mlt::Producer* service, const QString& target
     }
 
     // get temp filename
-    QTemporaryFile tmp;
-    tmp.open();
-    tmp.close();
-    MLT.saveXML(tmp.fileName(), service, false /* without relative paths */, false /* without verify */);
+    QScopedPointer<QTemporaryFile> tmp{Util::writableTemporaryFile(target)};
+    tmp->open();
+    tmp->close();
+    MLT.saveXML(tmp->fileName(), service, false /* without relative paths */, false /* without verify */);
 
     // parse xml
-    QFile f1(tmp.fileName());
+    QFile f1(tmp->fileName());
     f1.open(QIODevice::ReadOnly);
     QXmlSimpleReader xmlReader;
     QXmlInputSource xmlSource(&f1);
-    QDomDocument dom(tmp.fileName());
+    QDomDocument dom(tmp->fileName());
     dom.setContent(&xmlSource, &xmlReader);
     f1.close();
 
     // Check if the target file is a member of the project.
-    QString caption = tr("Export File");
     QString xml = dom.toString(0);
     if (xml.contains(QDir::fromNativeSeparators(target))) {
         QMessageBox::warning(this, caption,
                              tr("You cannot write to a file that is in your project.\n"
                                 "Try again with a different folder or file name."));
-        return 0;
+        return nullptr;
     }
 
-    if (Util::warnIfNotWritable(target, this, caption, true /* remove */))
-        return 0;
-
     // add consumer element
     QDomElement consumerNode = dom.createElement("consumer");
     QDomNodeList profiles = dom.elementsByTagName("profile");
@@ -1216,6 +1229,36 @@ Mlt::Producer *EncodeDock::fromProducer() const
         return 0;
 }
 
+void EncodeDock::filterX265Params(QStringList& other)
+{
+    auto i = 0;
+    auto x265ParamsKey = "x265-params=";
+    for (const auto& s : other) {
+        if (s.startsWith(x265ParamsKey))
+            break;
+        ++i;
+    }
+    if (i < other.size()) {
+        auto x265params = other[i].mid(::strlen(x265ParamsKey));
+        QStringList params;
+        for (const auto& s : x265params.split(':')) {
+            if (!s.isEmpty()
+                    && !s.startsWith("crf=")
+                    && !s.startsWith("bitrate=")
+                    && !s.startsWith("vbv-bufsize=")
+                    && !s.startsWith("vbv-maxrate=")
+                    && !s.startsWith("keyint=")
+                    && !s.startsWith("bframes=")
+                    && !s.startsWith("scenecut=")
+                    && !s.startsWith("interlace="))
+                params << s;
+        }
+        other.removeAt(i);
+        if (params.size() > 0)
+            other.insert(i, x265ParamsKey + params.join(':'));
+    }
+}
+
 static double getBufferSize(Mlt::Properties& preset, const char* property)
 {
     double size = preset.get_double(property);
@@ -1224,7 +1267,7 @@ static double getBufferSize(Mlt::Properties& preset, const char* property)
     if (s.endsWith('k')) size *= 1000;
     if (s.endsWith('M')) size *= 1000000;
     // convert to KiB
-    return double(qCeil(size / 1024 / 8 * 100)) / 100;
+    return double(qRound(size / 1024 / 8 * 100)) / 100;
 }
 
 void EncodeDock::on_presetsTree_clicked(const QModelIndex &index)
