@@ -37,6 +37,8 @@ class QQuickView;
 #   define MLT_LC_NAME     "LC_ALL"
 #endif
 
+#define MLT_VERSION_PREVIEW_SCALE ((6<<16)+(19<<8))
+#define MLT_VERSION_SET_STRING ((6<<16)+(19<<8))
 
 namespace Mlt {
 
@@ -72,7 +74,7 @@ public:
 
     virtual QObject* videoWidget() = 0;
     virtual int setProducer(Mlt::Producer*, bool isMulti = false);
-    virtual int open(const QString& url);
+    virtual int open(const QString& url, const QString& urlToSave);
     bool openXML(const QString& filename);
     virtual void close();
     virtual int displayWidth() const = 0;
@@ -88,7 +90,7 @@ public:
     double volume() const;
     void onWindowResize();
     virtual void seek(int position);
-    void refreshConsumer(bool scrubAudio = false);
+    virtual void refreshConsumer(bool scrubAudio = false);
     bool saveXML(const QString& filename, Service* service = nullptr, bool withRelativePaths = true, bool verify = true);
     QString XML(Service* service = nullptr, bool withProfile = false, bool withMetadata = false);
     int consumerChanged();
@@ -134,8 +136,11 @@ public:
     Mlt::Repository* repository() const {
         return m_repo;
     }
-    Mlt::Profile& profile() const {
-        return *m_profile;
+    Mlt::Profile& profile() {
+        return m_profile;
+    }
+    Mlt::Profile& previewProfile() {
+        return m_previewProfile;
     }
     Mlt::Producer* producer() const {
         return m_producer.data();
@@ -156,10 +161,12 @@ public:
     static Mlt::Filter* getFilter(const QString& name, Mlt::Service* service);
     QString projectFolder() const { return m_projectFolder; }
     void setProjectFolder(const QString& folderName);
-    QChar decimalPoint() const;
+    QChar decimalPoint();
     static void resetLocale();
     static int filterIn(Mlt::Playlist&playlist, int clipIndex);
     static int filterOut(Mlt::Playlist&playlist, int clipIndex);
+    void setPreviewScale(int scale);
+    void updatePreviewProfile();
 
 protected:
     Mlt::Repository* m_repo;
@@ -167,7 +174,8 @@ protected:
     QScopedPointer<Mlt::FilteredConsumer> m_consumer;
 
 private:
-    QScopedPointer<Mlt::Profile> m_profile;
+    Mlt::Profile m_profile;
+    Mlt::Profile m_previewProfile;
     int m_audioChannels{2};
     QScopedPointer<Mlt::Filter> m_jackFilter;
     QString m_url;
