@@ -56,9 +56,9 @@ MltXmlChecker::MltXmlChecker()
     , m_needsCPU(false)
     , m_hasEffects(false)
     , m_isCorrected(false)
+    , m_isUpdated(false)
     , m_usesLocale(false)
     , m_decimalPoint('.')
-    , m_tempFile(QDir::tempPath().append("/shotcut-XXXXXX.mlt"))
     , m_numericValueChanged(false)
 {
     m_unlinkedFilesModel.setColumnCount(ColumnCount);
@@ -69,12 +69,13 @@ bool MltXmlChecker::check(const QString& fileName)
     LOG_DEBUG() << "begin";
 
     QFile file(fileName);
-    if (file.open(QIODevice::ReadOnly | QIODevice::Text) &&
-            m_tempFile.open()) {
-        m_tempFile.resize(0);
+    m_tempFile.reset(new QTemporaryFile(
+        QFileInfo(fileName).dir().filePath("shotcut-XXXXXX.mlt")));
+    if (file.open(QIODevice::ReadOnly | QIODevice::Text) && m_tempFile->open()) {
+        m_tempFile->resize(0);
         m_fileInfo = QFileInfo(fileName);
         m_xml.setDevice(&file);
-        m_newXml.setDevice(&m_tempFile);
+        m_newXml.setDevice(m_tempFile.data());
         m_newXml.setAutoFormatting(true);
         m_newXml.setAutoFormattingIndent(2);
         if (m_xml.readNextStartElement()) {
@@ -83,7 +84,7 @@ bool MltXmlChecker::check(const QString& fileName)
                 m_newXml.writeCharacters("\n");
                 m_newXml.writeStartElement("mlt");
                 foreach (QXmlStreamAttribute a, m_xml.attributes()) {
-                    if (a.name().toString().toUpper() != MLT_LC_NAME) {
+                    if (a.name().toString().toUpper() != "LC_NUMERIC") {
                         m_newXml.writeAttribute(a);
                     } else {
                         QString value = a.value().toString().toUpper();
@@ -91,7 +92,7 @@ bool MltXmlChecker::check(const QString& fileName)
                         m_usesLocale = (value != "" && value != "C" && value != "POSIX" && QLocale().decimalPoint() != '.');
                         // Upon correcting the document to conform to current system,
                         // update the declared LC_NUMERIC.
-                        m_newXml.writeAttribute(MLT_LC_NAME, m_usesLocale? QLocale().name() : "C");
+                        m_newXml.writeAttribute("LC_NUMERIC", m_usesLocale? QLocale().name() : "C");
                     }
                 }
                 // We cannot apply the locale change to the session at this point
@@ -122,11 +123,13 @@ bool MltXmlChecker::check(const QString& fileName)
             }
         }
     }
-    if (m_tempFile.isOpen()) {
-        m_tempFile.close();
-//        m_tempFile.open();
-//        LOG_DEBUG() << m_tempFile.readAll().constData();
-//        m_tempFile.close();
+    if (m_tempFile->isOpen()) {
+        m_tempFile->close();
+
+        // Useful for debugging
+//        m_tempFile->open();
+//        LOG_DEBUG() << m_tempFile->readAll().constData();
+//        m_tempFile->close();
     }
     LOG_DEBUG() << "end";
     return m_xml.error() == QXmlStreamReader::NoError;
@@ -244,6 +247,7 @@ void MltXmlChecker::processProperties()
         checkCpuEffects(mlt_service);
         checkUnlinkedFile(mlt_service);
         checkIncludesSelf(newProperties);
+        checkLumaAlphaOver(mlt_service, newProperties);
 
         // Second pass: amend property values.
         m_properties = newProperties;
@@ -367,7 +371,7 @@ bool MltXmlChecker::readResourceProperty(const QString& name, QString& value)
     if (mlt_class == "filter" || mlt_class == "transition" || mlt_class == "producer")
     if (name == "resource" || name == "src" || name == "filename"
             || name == "luma" || name == "luma.resource" || name == "composite.luma"
-            || name == "producer.resource" || name == "av.file") {
+            || name == "producer.resource" || name == "av.file" || name == "warp_resource") {
 
         // Handle special prefix such as "plain:" or speed.
         m_resource.prefix = getPrefix(name, value);
@@ -482,3 +486,19 @@ void MltXmlChecker::checkIncludesSelf(QVector<MltProperty>& properties)
         m_isCorrected = true;
     }
 }
+
+void MltXmlChecker::checkLumaAlphaOver(const QString& mlt_service, QVector<MltXmlChecker::MltProperty>& properties)
+{
+    if (mlt_service == "luma") {
+        bool found = false;
+        for (auto& p : properties) {
+            if (p.first == "alpha_over") {
+                found = true;
+            }
+        }
+        if (!found) {
+            properties << MltProperty("alpha_over", "1");
+            m_isUpdated = true;
+        }
+    }
+}
