@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 Meltytech, LLC
+ * Copyright (c) 2013-2020 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -112,12 +112,31 @@ QRectF QmlFilter::getRect(QString name, int position)
     }
 }
 
+QStringList QmlFilter::getGradient(QString name)
+{
+    QStringList list;
+    for (int i = 1; i <= 10; i++) {
+        QString colorName = name + "." + QString::number(i);
+        const char* value = m_filter.get(colorName.toUtf8().constData());
+        if (value) {
+            list.append(QString::fromUtf8(value));
+        } else {
+            break;
+        }
+    }
+    return list;
+}
+
 void QmlFilter::set(QString name, QString value, int position)
 {
     if (!m_filter.is_valid()) return;
     if (position < 0) {
         if (qstrcmp(m_filter.get(name.toUtf8().constData()), value.toUtf8().constData())) {
+#if LIBMLT_VERSION_INT >= MLT_VERSION_SET_STRING 
+            m_filter.set_string(name.toUtf8().constData(), value.toUtf8().constData());
+#else
             m_filter.set(name.toUtf8().constData(), value.toUtf8().constData());
+#endif
             emit changed(name);
         }
     } else {
@@ -219,6 +238,19 @@ void QmlFilter::set(QString name, double x, double y, double width, double heigh
     }
 }
 
+void QmlFilter::setGradient(QString name, const QStringList& gradient)
+{
+    for (int i = 1; i <= 10;  i++) {
+        QString colorName = name + "." + QString::number(i);
+        if (i <= gradient.length()) {
+            m_filter.set(colorName.toUtf8().constData(), gradient[i-1].toUtf8().constData());
+        } else {
+            m_filter.clear(colorName.toUtf8().constData());
+        }
+    }
+    emit changed();
+}
+
 void QmlFilter::set(QString name, const QRectF& rect, double opacity, int position, mlt_keyframe_type keyframeType)
 {
     set(name, rect.x(), rect.y(), rect.width(), rect.height(), opacity, position, keyframeType);
@@ -233,7 +265,12 @@ void QmlFilter::loadPresets()
         foreach (QString s, entries) {
             if (s == objectNameOrService() && dir.cd(s)) {
                 m_presets.append("");
-                m_presets.append(dir.entryList(QDir::Files | QDir::Readable));
+                for (auto& s : dir.entryList(QDir::Files | QDir::Readable)) {
+                    if (s == QUrl::toPercentEncoding(QUrl::fromPercentEncoding(s.toUtf8())))
+                        m_presets << QUrl::fromPercentEncoding(s.toUtf8());
+                    else
+                        m_presets << s;
+                }
                 break;
             }
         }
@@ -258,7 +295,7 @@ int QmlFilter::savePreset(const QStringList &propertyNames, const QString &name)
         if (dir.mkdir(objectNameOrService()))
             dir.cd(objectNameOrService());
     }
-    const QString preset = name.isEmpty()? tr("(defaults)") : name;
+    QString preset = name.isEmpty()? tr("(defaults)") : QString::fromUtf8(QUrl::toPercentEncoding(name));
 #if LIBMLT_VERSION_INT >= ((6<<16)+(9<<8))
     // Convert properties to YAML string.
     char* yamlStr = properties.serialise_yaml();
@@ -281,8 +318,10 @@ int QmlFilter::savePreset(const QStringList &propertyNames, const QString &name)
 void QmlFilter::deletePreset(const QString &name)
 {
     QDir dir(Settings.appDataLocation());
-    if (dir.cd("presets") && dir.cd(objectNameOrService()))
-        QFile(dir.filePath(name)).remove();
+    if (dir.cd("presets") && dir.cd(objectNameOrService())) {
+        if (!QFile(dir.filePath(QUrl::toPercentEncoding(name))).remove())
+            QFile(dir.filePath(name)).remove();
+    }
     m_presets.removeOne(name);
     emit presetsChanged();
 }
@@ -292,26 +331,27 @@ void QmlFilter::analyze(bool isAudio)
     Mlt::Service service(mlt_service(m_filter.get_data("service")));
 
     // get temp filename for input xml
-    QTemporaryFile tmp;
-    tmp.open();
-    tmp.close();
-    m_filter.set("results", NULL, 0);
+    QString filename(m_filter.get("filename"));
+    QScopedPointer<QTemporaryFile> tmp(Util::writableTemporaryFile(filename));
+    tmp->open();
+    tmp->close();
+    m_filter.set("results", nullptr, 0);
     int disable = m_filter.get_int("disable");
     m_filter.set("disable", 0);
     if (!isAudio) m_filter.set("analyze", 1);
-    MLT.saveXML(tmp.fileName(), &service, false, false);
+    MLT.saveXML(tmp->fileName(), &service, false, false);
     if (!isAudio) m_filter.set("analyze", 0);
     m_filter.set("disable", disable);
 
     // get temp filename for output xml
-    QTemporaryFile tmpTarget;
-    tmpTarget.open();
-    tmpTarget.close();
+    QScopedPointer<QTemporaryFile> tmpTarget(Util::writableTemporaryFile(filename));
+    tmpTarget->open();
+    tmpTarget->close();
 
     // parse xml
-    QFile f1(tmp.fileName());
+    QFile f1(tmp->fileName());
     f1.open(QIODevice::ReadOnly);
-    QDomDocument dom(tmp.fileName());
+    QDomDocument dom(tmp->fileName());
     dom.setContent(&f1);
     f1.close();
 
@@ -329,9 +369,9 @@ void QmlFilter::analyze(bool isAudio)
     else
         consumerNode.setAttribute("audio_off", 1);
     consumerNode.setAttribute("no_meta", 1);
-    consumerNode.setAttribute("resource", tmpTarget.fileName());
+    consumerNode.setAttribute("resource", tmpTarget->fileName());
 
-    AbstractJob* job = new MeltJob(tmpTarget.fileName(), dom.toString(2),
+    AbstractJob* job = new MeltJob(tmpTarget->fileName(), dom.toString(2),
         MLT.profile().frame_rate_num(), MLT.profile().frame_rate_den());
     if (job) {
         AnalyzeDelegate* delegate = new AnalyzeDelegate(m_filter);
@@ -342,7 +382,6 @@ void QmlFilter::analyze(bool isAudio)
 
         // Touch the target .stab file. This prevents multiple jobs from trying
         // to write the same file.
-        QString filename(m_filter.get("filename"));
         if (!filename.isEmpty() && !QFile::exists(filename)) {
             job->setProperty("filename", filename);
             QFile file(filename);
@@ -494,6 +533,7 @@ int QmlFilter::keyframeCount(const QString& name)
 void QmlFilter::resetProperty(const QString& name)
 {
     m_filter.clear(name.toUtf8().constData());
+    emit changed();
 }
 
 void QmlFilter::clearSimpleAnimation(const QString& name)
@@ -513,20 +553,31 @@ void QmlFilter::preset(const QString &name)
     if (!dir.cd("presets") || !dir.cd(objectNameOrService()))
         return;
 
+    auto fileName = dir.filePath(QUrl::toPercentEncoding(name));
+
 #if LIBMLT_VERSION_INT >= ((6<<16)+(9<<8))
     // Detect the preset file format
     bool isYaml = false;
-    QFile presetFile(dir.filePath(name));
-    if(presetFile.open(QIODevice::ReadOnly)) {
+    QFile presetFile(fileName);
+    if (presetFile.open(QIODevice::ReadOnly)) {
         if(presetFile.readLine(4) == "---") {
             isYaml = true;
         }
         presetFile.close();
+    } else {
+        presetFile.setFileName(dir.filePath(name));
+        if (presetFile.open(QIODevice::ReadOnly)) {
+            fileName = dir.filePath(name);
+            if(presetFile.readLine(4) == "---") {
+                isYaml = true;
+            }
+            presetFile.close();
+        }
     }
 
     if(isYaml) {
         // Load from YAML file.
-        QScopedPointer<Mlt::Properties> properties(Mlt::Properties::parse_yaml(dir.filePath(name).toUtf8().constData()));
+        QScopedPointer<Mlt::Properties> properties(Mlt::Properties::parse_yaml(fileName.toUtf8().constData()));
         if (properties && properties->is_valid()) {
             QChar decimalPoint = MLT.decimalPoint();
             for (int i = 0; i < properties->count(); i++) {
@@ -542,10 +593,10 @@ void QmlFilter::preset(const QString &name)
         }
     } else {
         // Load from legacy preset file
-        m_filter.load(dir.filePath(name).toUtf8().constData());
+        m_filter.load(fileName.toUtf8().constData());
     }
 #else
-    m_filter.load(dir.filePath(name).toUtf8().constData());
+    m_filter.load(fileName.toUtf8().constData());
 #endif
 
     emit changed();
@@ -589,6 +640,13 @@ mlt_keyframe_type QmlFilter::getKeyframeType(Mlt::Animation& animation, int posi
     return result;
 }
 
+bool QmlFilter::isAtLeastVersion(const QString& version)
+{
+    QVersionNumber v1 = QVersionNumber::fromString(version);
+    QVersionNumber v2 = QVersionNumber::fromString(m_metadata->property("version").toString());
+    return v2 >= v1;
+}
+
 AnalyzeDelegate::AnalyzeDelegate(Mlt::Filter& filter)
     : QObject(0)
 #if LIBMLT_VERSION_INT >= MLT_VERSION_CPP_UPDATED
