@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 Meltytech, LLC
+ * Copyright (c) 2013-2020 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ class ShotcutSettings : public QObject
     Q_PROPERTY(double audioOutDuration READ audioOutDuration WRITE setAudioOutDuration NOTIFY audioOutDurationChanged)
     Q_PROPERTY(double videoInDuration READ videoInDuration WRITE setVideoInDuration NOTIFY videoInDurationChanged)
     Q_PROPERTY(double videoOutDuration READ videoOutDuration WRITE setVideoOutDuration NOTIFY videoOutDurationChanged)
+    Q_PROPERTY(bool smallIcons READ smallIcons WRITE setSmallIcons NOTIFY smallIconsChanged)
 
 public:
     static ShotcutSettings& singleton();
@@ -124,6 +125,8 @@ public:
     void setPlayerVolume(int);
     float playerZoom() const;
     void setPlayerZoom(float);
+    int playerPreviewScale() const;
+    void setPlayerPreviewScale(int);
 
     QString playlistThumbnails() const;
     void setPlaylistThumbnails(const QString&);
@@ -190,6 +193,8 @@ public:
 
     QString projectsFolder() const;
     void setProjectsFolder(const QString& path);
+    
+    int undoLimit() const;
 
 signals:
     void openPathChanged();
@@ -208,6 +213,7 @@ signals:
     void videoOutDurationChanged();
     void playlistThumbnailsChanged();
     void viewModeChanged();
+    void smallIconsChanged();
 
 private:
     QSettings settings;
